@@ -91,7 +91,7 @@
   # for polr, we need to fix parameter names
   params$Parameter <- gsub("Intercept: ", "", params$Parameter, fixed = TRUE)
 
-  # sanity check...
+  # validation check...
   if (is.null(method)) {
     method <- "wald"
   }
@@ -118,7 +118,7 @@
     }
 
     # if we have a non-empty stderror, use it
-    if (datawizard::is_empty_object(stderror)) {
+    if (insight::is_empty_object(stderror)) {
       return(NULL)
     }
 
