@@ -1,7 +1,10 @@
 .ci_profiled <- function(model, ci) {
   glm_ci <- tryCatch(
     {
-      out <- as.data.frame(stats::confint(model, level = ci), stringsAsFactors = FALSE)
+      out <- as.data.frame(
+        suppressWarnings(stats::confint(model, level = ci)),
+        stringsAsFactors = FALSE
+      )
       names(out) <- c("CI_low", "CI_high")
 
       out$CI <- ci
@@ -77,14 +80,18 @@
 
 #' @keywords internal
 .ci_profile_glmmTMB <- function(x, ci, profiled, component, ...) {
+  # make sure "..." doesn't pass invalid arguments to package TMB
+  dot_args <- .check_profile_uniroot_args(...)
+
   if (is.null(profiled)) {
-    out <- as.data.frame(stats::confint(x, method = "profile", level = ci, ...))
+    args <- list(x, method = "profile", level = ci, dot_args)
+    out <- as.data.frame(do.call(stats::confint, args))
   } else {
-    out <- tryCatch(as.data.frame(stats::confint(profiled, level = ci, ...)),
-      error = function(e) NULL
-    )
+    args <- list(profiled, level = ci, dot_args)
+    out <- .safe(as.data.frame(do.call(stats::confint, args)))
     if (is.null(out)) {
-      out <- as.data.frame(stats::confint(x, method = "profile", level = ci, ...))
+      args <- list(x, method = "profile", level = ci, dot_args)
+      out <- as.data.frame(do.call(stats::confint, args))
     }
   }
   .process_glmmTMB_CI(x, out, ci, component)
@@ -94,11 +101,29 @@
 
 #' @keywords internal
 .ci_uniroot_glmmTMB <- function(x, ci, component, ...) {
-  out <- as.data.frame(stats::confint(x, level = ci, method = "uniroot", ...))
+  # make sure "..." doesn't pass invalid arguments to package TMB
+  dot_args <- .check_profile_uniroot_args(...)
+  args <- list(x, level = ci, method = "uniroot", dot_args)
+  out <- as.data.frame(do.call(stats::confint, args))
   .process_glmmTMB_CI(x, out, ci, component)
 }
 
 
+.check_profile_uniroot_args <- function(...) {
+  .profile_formals <- c(
+    "cl", "fitted", "h", "level_max", "lincomb", "maxit", "name",
+    "ncpus", "npts", "obj", "parallel", "parm", "parm.range", "slice",
+    "stderr", "stepfac", "trace", "ystep", "ytol"
+  )
+  dots <- list(...)
+  dot_args <- intersect(names(dots), .profile_formals)
+  out <- dots[dot_args]
+  if (!length(out)) {
+    return(NULL)
+  }
+  out
+}
+
 
 .process_glmmTMB_CI <- function(x, out, ci, component) {
   rownames(out) <- gsub("`", "", rownames(out), fixed = TRUE)
@@ -110,9 +135,9 @@
   )
 
   param_names <- switch(component,
-    "conditional" = pars$Parameter,
-    "zi" = ,
-    "zero_inflated" = paste0("zi~", pars$Parameter),
+    conditional = pars$Parameter,
+    zi = ,
+    zero_inflated = paste0("zi~", pars$Parameter),
     c(
       pars$Parameter[pars$Component == "conditional"],
       paste0("zi~", pars$Parameter[pars$Component == "zero_inflated"])
@@ -138,7 +163,9 @@
   insight::check_if_installed("lme4")
 
   # Compute
-  out <- suppressWarnings(suppressMessages(as.data.frame(lme4::confint.merMod(x, level = ci, method = "boot", nsim = iterations, ...))))
+  out <- suppressWarnings(suppressMessages(as.data.frame(
+    lme4::confint.merMod(x, level = ci, method = "boot", nsim = iterations, ...)
+  )))
   rownames(out) <- gsub("`", "", rownames(out), fixed = TRUE)
   out <- out[rownames(out) %in% insight::find_parameters(x, effects = "fixed")$conditional, ]
   names(out) <- c("CI_low", "CI_high")
