@@ -43,7 +43,7 @@ model_parameters.cgam <- function(model,
                                   drop = NULL,
                                   verbose = TRUE,
                                   ...) {
-  # sanity check, warn if unsupported argument is used.
+  # validation check, warn if unsupported argument is used.
   dot_args <- .check_dots(
     dots = list(...),
     not_allowed = c("vcov", "vcov_args", "component"),
@@ -119,7 +119,7 @@ model_parameters.cgam <- function(model,
     params$CI[is.na(params$CI_low)] <- NA
   }
 
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
   params
