@@ -1,4 +1,3 @@
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.ggeffects <- function(model, keep = NULL, drop = NULL, verbose = TRUE, ...) {
   ci <- attributes(model)$ci.lvl
@@ -110,6 +109,9 @@ model_parameters.ggeffects <- function(model, keep = NULL, drop = NULL, verbose
     if (is.null(.model)) {
       .model <- .safe(get(obj_name, envir = globalenv()))
     }
+    if (is.null(.model)) {
+      .model <- .safe(.dynGet(obj_name))
+    }
   }
   .model
 }
